( cd usr/bin ; rm -rf grep )
( cd usr/bin ; ln -sf ../../bin/grep grep )
( cd usr/bin ; rm -rf fgrep )
( cd usr/bin ; ln -sf ../../bin/fgrep fgrep )
( cd usr/bin ; rm -rf egrep )
( cd usr/bin ; ln -sf ../../bin/egrep egrep )
